==> findbugs-1.3.8-source.zip: findbugs-1.3.8/src/java/edu/umd/cs/findbugs/detect/NoteAnnotationRetention.java <==
/*
 * FindBugs - Find bugs in Java programs
 * Copyright (C) 2004-2006 University of Maryland
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

package edu.umd.cs.findbugs.detect;

import java.util.Map;

import org.apache.bcel.classfile.JavaClass;

import edu.umd.cs.findbugs.BugReporter;
import edu.umd.cs.findbugs.Detector;
import edu.umd.cs.findbugs.NonReportingDetector;
import edu.umd.cs.findbugs.ba.AnalysisContext;
import edu.umd.cs.findbugs.ba.ClassContext;
import edu.umd.cs.findbugs.bcel.BCELUtil;
import edu.umd.cs.findbugs.visitclass.AnnotationVisitor;

public class NoteAnnotationRetention extends AnnotationVisitor implements
		Detector, NonReportingDetector {

		private boolean runtimeRetention;


	public NoteAnnotationRetention(BugReporter bugReporter) {
	}

	@Override
	public void visitAnnotation(String annotationClass,
			Map<String, Object> map, boolean runtimeVisible) {

		if (!annotationClass.equals("java.lang.annotation.Retention"))
			return;
		Object value = map.get("value");
		if ("java.lang.annotation.RetentionPolicy.RUNTIME".equals(value))
			runtimeRetention = true;
	}

	@Override
	public void visit(JavaClass obj) {
		runtimeRetention = false;
	}

	@Override
	public void visitAfter(JavaClass obj) {
		for (String i : obj.getInterfaceNames())
			if (i.equals("java.lang.annotation.Annotation"))
				AnalysisContext.currentAnalysisContext()
				.getAnnotationRetentionDatabase().setRuntimeRetention(getDottedClassName(),
						runtimeRetention);

	}

	public void visitClassContext(ClassContext classContext) {
		JavaClass javaClass = classContext.getJavaClass();
		if  (!BCELUtil.preTiger(javaClass)) javaClass.accept(this);

	}


	public void report() {

	}


}

==> findbugs-1.3.9-source.zip: findbugs-1.3.9/src/java/edu/umd/cs/findbugs/detect/NoteAnnotationRetention.java <==
/*
 * FindBugs - Find bugs in Java programs
 * Copyright (C) 2004-2006 University of Maryland
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

package edu.umd.cs.findbugs.detect;

import java.util.Map;

import org.apache.bcel.classfile.JavaClass;

import edu.umd.cs.findbugs.BugReporter;
import edu.umd.cs.findbugs.Detector;
import edu.umd.cs.findbugs.FirstPassDetector;
import edu.umd.cs.findbugs.NonReportingDetector;
import edu.umd.cs.findbugs.ba.AnalysisContext;
import edu.umd.cs.findbugs.ba.ClassContext;
import edu.umd.cs.findbugs.bcel.BCELUtil;
import edu.umd.cs.findbugs.visitclass.AnnotationVisitor;

public class NoteAnnotationRetention extends AnnotationVisitor implements
		Detector, NonReportingDetector, FirstPassDetector {

		private boolean runtimeRetention;


	public NoteAnnotationRetention(BugReporter bugReporter) {
	}

	@Override
	public void visitAnnotation(String annotationClass,
			Map<String, Object> map, boolean runtimeVisible) {

		if (!annotationClass.equals("java.lang.annotation.Retention"))
			return;
		Object value = map.get("value");
		if ("java.lang.annotation.RetentionPolicy.RUNTIME".equals(value))
			runtimeRetention = true;
	}

	@Override
	public void visit(JavaClass obj) {
		runtimeRetention = false;
	}

	@Override
	public void visitAfter(JavaClass obj) {
		for (String i : obj.getInterfaceNames())
			if (i.equals("java.lang.annotation.Annotation"))
				AnalysisContext.currentAnalysisContext()
				.getAnnotationRetentionDatabase().setRuntimeRetention(getDottedClassName(),
						runtimeRetention);

	}

	public void visitClassContext(ClassContext classContext) {
		JavaClass javaClass = classContext.getJavaClass();
		if  (!BCELUtil.preTiger(javaClass)) javaClass.accept(this);

	}


	public void report() {

	}


}
